@@ -1,6 +1,9 @@
 """
 Integration (not unit) tests for pylast.py
 """
+
+from __future__ import annotations
+
 import time
 
 import pytest
@@ -135,11 +138,7 @@ class TestPyLastTrack(TestPyLastWithLastFm):
         similar = track.get_similar()
 
         # Assert
-        found = False
-        for track in similar:
-            if str(track.item) == "Madonna - Vogue":
-                found = True
-                break
+        found = any(str(track.item) == "Cher - Strong Enough" for track in similar)
         assert found
 
     def test_track_get_similar_limits(self) -> None:
